@@ -21,11 +21,11 @@ def clear_render_border():
     pass
 
 
-def curves_point_set(point: typing.Union[int, str] = 'BLACK_POINT'):
+def curves_point_set(point: typing.Union[str, int] = 'BLACK_POINT'):
     ''' Set black point or white point for curves
 
     :param point: Point, Set black point or white point for curves
-    :type point: typing.Union[int, str]
+    :type point: typing.Union[str, int]
     '''
 
     pass
@@ -83,9 +83,9 @@ def new(name: str = "Untitled",
         height: int = 1024,
         color: typing.List[float] = (0.0, 0.0, 0.0, 1.0),
         alpha: bool = True,
-        generated_type: typing.Union[int, str] = 'BLANK',
+        generated_type: typing.Union[str, int] = 'BLANK',
         float: bool = False,
-        gen_context: typing.Union[int, str] = 'NONE',
+        gen_context: typing.Union[str, int] = 'NONE',
         use_stereo_3d: bool = False):
     ''' Create a new image
 
@@ -100,11 +100,11 @@ def new(name: str = "Untitled",
     :param alpha: Alpha, Create an image with an alpha channel
     :type alpha: bool
     :param generated_type: Generated Type, Fill the image with a grid for UV map testing * BLANK Blank, Generate a blank image. * UV_GRID UV Grid, Generated grid to test UV mappings. * COLOR_GRID Color Grid, Generated improved UV grid to test UV mappings.
-    :type generated_type: typing.Union[int, str]
+    :type generated_type: typing.Union[str, int]
     :param float: 32 bit Float, Create image with 32 bit floating point bit depth
     :type float: bool
     :param gen_context: Gen Context, Generation context
-    :type gen_context: typing.Union[int, str]
+    :type gen_context: typing.Union[str, int]
     :param use_stereo_3d: Stereo 3D, Create an image with left and right views
     :type use_stereo_3d: bool
     '''
@@ -114,8 +114,10 @@ def new(name: str = "Untitled",
 
 def open(filepath: str = "",
          directory: str = "",
-         files: typing.Union[typing.List['bpy.types.OperatorFileListElement'],
-                             'bpy_prop_collection'] = None,
+         files: typing.
+         Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.
+               List['bpy.types.OperatorFileListElement'],
+               'bpy_prop_collection'] = None,
          filter_blender: bool = False,
          filter_backup: bool = False,
          filter_image: bool = True,
@@ -133,8 +135,8 @@ def open(filepath: str = "",
          relative_path: bool = True,
          show_multiview: bool = False,
          use_multiview: bool = False,
-         display_type: typing.Union[int, str] = 'DEFAULT',
-         sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
+         display_type: typing.Union[str, int] = 'DEFAULT',
+         sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Open image
 
     :param filepath: File Path, Path to file
@@ -142,7 +144,7 @@ def open(filepath: str = "",
     :param directory: Directory, Directory of the file
     :type directory: str
     :param files: Files
-    :type files: typing.Union[typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
+    :type files: typing.Union[typing.Dict[str, 'bpy.types.OperatorFileListElement'], typing.List['bpy.types.OperatorFileListElement'], 'bpy_prop_collection']
     :param filter_blender: Filter .blend files
     :type filter_blender: bool
     :param filter_backup: Filter .blend files
@@ -178,9 +180,9 @@ def open(filepath: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
@@ -270,8 +272,8 @@ def replace(filepath: str = "",
             relative_path: bool = True,
             show_multiview: bool = False,
             use_multiview: bool = False,
-            display_type: typing.Union[int, str] = 'DEFAULT',
-            sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
+            display_type: typing.Union[str, int] = 'DEFAULT',
+            sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Replace current image by another one from disk
 
     :param filepath: File Path, Path to file
@@ -311,9 +313,9 @@ def replace(filepath: str = "",
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
@@ -378,8 +380,8 @@ def save_as(save_as_render: bool = False,
             relative_path: bool = True,
             show_multiview: bool = False,
             use_multiview: bool = False,
-            display_type: typing.Union[int, str] = 'DEFAULT',
-            sort_method: typing.Union[int, str] = 'FILE_SORT_ALPHA'):
+            display_type: typing.Union[str, int] = 'DEFAULT',
+            sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
     ''' Save the image with another name and/or settings
 
     :param save_as_render: Save As Render, Apply render part of display transform when saving byte image
@@ -425,9 +427,9 @@ def save_as(save_as_render: bool = False,
     :param use_multiview: Use Multi-View
     :type use_multiview: bool
     :param display_type: Display Type * DEFAULT Default, Automatically determine display type for files. * LIST_SHORT Short List, Display files as short list. * LIST_LONG Long List, Display files as a detailed list. * THUMBNAIL Thumbnails, Display files as thumbnails.
-    :type display_type: typing.Union[int, str]
+    :type display_type: typing.Union[str, int]
     :param sort_method: File sorting mode * FILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically. * FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type. * FILE_SORT_TIME Sort by time, Sort files by modification time. * FILE_SORT_SIZE Sort by size, Sort files by size.
-    :type sort_method: typing.Union[int, str]
+    :type sort_method: typing.Union[str, int]
     '''
 
     pass
@@ -457,11 +459,11 @@ def toolshelf():
     pass
 
 
-def unpack(method: typing.Union[int, str] = 'USE_LOCAL', id: str = ""):
+def unpack(method: typing.Union[str, int] = 'USE_LOCAL', id: str = ""):
     ''' Save an image packed in the .blend file to disk
 
     :param method: Method, How to unpack
-    :type method: typing.Union[int, str]
+    :type method: typing.Union[str, int]
     :param id: Image Name, Image datablock name to unpack
     :type id: str
     '''
