@@ -1299,13 +1299,13 @@ def primitive_plane_add(
 
 
 def primitive_torus_add(
-        rotation: typing.List[float] = (0.0, 0.0, 0.0),
         view_align: bool = False,
         layers: typing.List[bool] = (False, False, False, False, False, False,
                                      False, False, False, False, False, False,
                                      False, False, False, False, False, False,
                                      False, False),
         location: typing.List[float] = (0.0, 0.0, 0.0),
+        rotation: typing.List[float] = (0.0, 0.0, 0.0),
         major_segments: int = 48,
         minor_segments: int = 12,
         mode: typing.Union[str, int] = 'MAJOR_MINOR',
@@ -1315,14 +1315,14 @@ def primitive_torus_add(
         abso_minor_rad: float = 0.75):
     ''' Add a torus mesh
 
-    :param rotation: Rotation
-    :type rotation: typing.List[float]
     :param view_align: Align to View
     :type view_align: bool
     :param layers: Layers
     :type layers: typing.List[bool]
     :param location: Location
     :type location: typing.List[float]
+    :param rotation: Rotation
+    :type rotation: typing.List[float]
     :param major_segments: Major Segments, Number of segments for the main ring of the torus
     :type major_segments: int
     :param minor_segments: Minor Segments, Number of segments for the minor ring of the torus
@@ -1657,7 +1657,7 @@ def select_more(use_face_step: bool = True):
 
 
 def select_next_item():
-    ''' Select the next element (using selection order)
+    ''' Select the next element (using selection order) :file: startup/bl_operators/mesh.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/mesh.py> _:163
 
     '''
 
@@ -1704,7 +1704,7 @@ def select_nth(nth: int = 2, skip: int = 1, offset: int = 0):
 
 
 def select_prev_item():
-    ''' Select the next element (using selection order)
+    ''' Select the next element (using selection order) :file: startup/bl_operators/mesh.py <https://developer.blender.org/diffusion/B/browse/master/release/scripts/ /startup/bl_operators/mesh.py> _:188
 
     '''
 
