@@ -1,7 +1,7 @@
 import sys
 import typing
-from . import previews
 from . import units
+from . import previews
 
 
 def blend_paths(absolute: bool = False,
@@ -200,11 +200,11 @@ def smpte_from_frame(frame: int, fps=None, fps_base=None) -> str:
     pass
 
 
-def smpte_from_seconds(time: typing.Union[int, float], fps=None) -> str:
+def smpte_from_seconds(time: typing.Union[float, int], fps=None) -> str:
     ''' Returns an SMPTE formatted string from the *time*: HH:MM:SS:FF . If the *fps* is not given the current scene is used.
 
     :param time: time in seconds.
-    :type time: typing.Union[int, float]
+    :type time: typing.Union[float, int]
     :return: the frame string.
     '''
 
